@@ -21,10 +21,8 @@
 #ifndef WIDGETFACTORY_H
 #define WIDGETFACTORY_H
 
-#include "filemetadatawidget.h"
-
-#include <QObject>
-#include <QStringList>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
 
 class KJob;
 class QUrl;
@@ -40,17 +38,14 @@ namespace Baloo {
     {
         Q_OBJECT
     public:
-        explicit WidgetFactory(QObject* parent = nullptr);
-        ~WidgetFactory() override;
+        explicit WidgetFactory(QObject* parent = 0);
+        virtual ~WidgetFactory();
 
-        void setItems(const KFileItemList& items);
+        void setItems(const QStringList& items);
 
         void setReadOnly(bool value);
         void setNoLinks(bool value);
 
-        void setDateFormat(const DateFormats format);
-        DateFormats dateFormat() const;
-
         QWidget* createWidget(const QString& prop, const QVariant& value, QWidget* parent);
 
     Q_SIGNALS:
@@ -76,11 +71,10 @@ namespace Baloo {
         KRatingWidget* m_ratingWidget;
         KCommentWidget* m_commentWidget;
 
-        KFileItemList m_items;
+        QStringList m_items;
         QStringList m_prevTags;
         bool m_readOnly;
         bool m_noLinks;
-        QLocale::FormatType m_dateFormat;
     };
 }
 
