@@ -19,17 +19,17 @@
 
 #include "filemetadataconfigwidget.h"
 
-#include <QApplication>
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QCheckBox>
-#include <QFileDialog>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QVBoxLayout>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QFileDialog>
 
 class FileMetadataWidgetTest : public QWidget
 {
     Q_OBJECT
 public:
-    explicit FileMetadataWidgetTest(QWidget* parent = nullptr, Qt::WindowFlags f = {});
+    explicit FileMetadataWidgetTest(QWidget* parent = 0, Qt::WindowFlags f = 0);
 
 private Q_SLOTS:
     void slotChooseFiles();
@@ -54,9 +54,9 @@ FileMetadataWidgetTest::FileMetadataWidgetTest(QWidget* parent, Qt::WindowFlags
 
 void FileMetadataWidgetTest::slotChooseFiles()
 {
-    const QList<QUrl> urlList = QFileDialog::getOpenFileUrls();
+    QList<QUrl> urlList = QFileDialog::getOpenFileUrls();
     KFileItemList list;
-    for (const QUrl& url : urlList)
+    foreach(const QUrl& url, urlList)
         list << KFileItem( url, QString(), mode_t() );
 
     m_metadataWidget->setItems( list );
@@ -65,7 +65,7 @@ void FileMetadataWidgetTest::slotChooseFiles()
 int main( int argc, char** argv )
 {
     QApplication app( argc, argv );
-    app.setApplicationName(QStringLiteral("FileMetaDataConfigWidgetApp"));
+    app.setApplicationName( "FileMetaDataConfigWidgetApp" );
     FileMetadataWidgetTest test;
     test.show();
     return app.exec();
